@@ -5,8 +5,8 @@ function TinyImagesFileBrowser(field_name, url, type, win) {
     
     tinyMCE.selectedInstance.windowManager.open({
         url: cmsURL,
-        width: 500,  // Your dimensions may differ - toy around with them!
-        height: 500,
+        width: 600,  // Your dimensions may differ - toy around with them!
+        height: 560,
         resizable: "yes",
         scrollbars: "yes",
         inline: "no",  // This parameter only has an effect if you use the inlinepopups plugin!
@@ -17,12 +17,17 @@ function TinyImagesFileBrowser(field_name, url, type, win) {
     return false;
 }
 
+function update_field(field, value) {
+    if (field) field.value=value;
+}
+
 function returnURL(url, alt, width, height) {
 	var win = tinyMCEPopup.features['win']
 
 	win.document.getElementById(tinyMCEPopup.features['field_name']).value = url;
-	win.document.getElementById("alt").value = alt;
-	win.document.getElementById("width").value = width;
-	win.document.getElementById("height").value = height;
+	update_field(win.document.getElementById("alt"), alt);
+	update_field(win.document.getElementById("linktitle"), alt);
+	update_field(win.document.getElementById("width"), width);
+	update_field(win.document.getElementById("height"), height);
 	tinyMCEPopup.close();
 }
