@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 """
 Base classes for writing Merengue management commands (to be executed
 through ``merengue-admin.py``).
@@ -39,7 +56,7 @@ def copy_helper(style, name, directory, symlink=False):
     # directory -- The directory to which the layout template should be copied.
     import re
     from merengue import settings as merengue_settings
-    if not re.search(r'^[_a-zA-Z]\w*$', name): # If it's not a valid directory name.
+    if not re.search(r'^[_a-zA-Z]\w*$', name):  # If it's not a valid directory name.
         # Provide a smart error message, depending on the error.
         if not re.search(r'^[_a-zA-Z]', name):
             message = 'make sure the name begins with a letter or underscore'
@@ -70,16 +87,19 @@ def copy_merengue_dirs(style, name, merengue_root, top_dir, symlink, remove_if_e
 
     if sys.platform == 'win32':
         message = "Linking is not supported by this platform (%s), copying instead." % sys.platform
-        sys.stderr.write(style.NOTICE(message % sys.platform))
+        sys.stderr.write(style.NOTICE(message))
         symlink = False
         symlink_possible = False
     else:
         symlink_possible = True
 
     # Symlink "merengue" top dir
-    if symlink_possible:
+    if symlink:
         dest = os.path.join(top_dir, 'merengue')
         make_symlink(merengue_root, dest, remove_if_exists)
+    else:
+        dest = os.path.join(top_dir, 'merengue')
+        copy_dir(merengue_root, dest, name, remove_if_exists, style)
 
     # Copy or symlink merengue plugins
     dest = os.path.join(top_dir, 'plugins')
@@ -98,26 +118,11 @@ def copy_merengue_dirs(style, name, merengue_root, top_dir, symlink, remove_if_e
     else:
         make_symlink(os.path.join('..', 'merengue', 'media'), merengue_media_dir, remove_if_exists)
 
-    # Symlink apps' media
-    apps_dir = os.path.join(merengue_root, 'apps')
-    for app in os.listdir(apps_dir):
-        if app.startswith('.'):
-            continue # we ignore hidden directories
-        dest = os.path.join(top_dir, 'media', app)
-        app_media_dir = os.path.join(apps_dir, app, 'media')
-        if os.path.isdir(app_media_dir):
-            if not symlink_possible:
-                message = "Linking is not supported by this platform (%s), copying apps/%s/media instead."
-                sys.stderr.write(style.NOTICE(message % (sys.platform, app)))
-                copy_dir(app_media_dir, dest, name, remove_if_exists, style)
-            else:
-                make_symlink(os.path.join('..', 'merengue', 'apps', app, 'media'), dest, remove_if_exists)
-
     # Copy or symlink default themes' media and templates
     themes_dir = os.path.join(merengue_root, 'themes')
     for theme in os.listdir(themes_dir):
         if theme.startswith('.'):
-            continue # we ignore hidden directories
+            continue  # we ignore hidden directories
         theme_dir = os.path.join(themes_dir, theme)
         dest_media = os.path.join(top_dir, 'media', 'themes', theme)
         dest_templates = os.path.join(top_dir, 'templates', 'themes', theme)
@@ -150,7 +155,7 @@ def copy_dir(source, dest, name, remove_if_exists, style, link=False):
         os.makedirs(dest)
 
     for d, subdirs, files in os.walk(source):
-        relative_dir = d[len(source)+1:].replace('project_name', name)
+        relative_dir = d[len(source) + 1:].replace('project_name', name)
         new_relative_dir = os.path.join(dest, relative_dir)
         if not os.path.exists(new_relative_dir):
             os.makedirs(new_relative_dir)
