@@ -1,4 +1,4 @@
-# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+# Copyright (c) 2010 by Yaco Sistemas
 #
 # This file is part of Merengue.
 #
@@ -22,16 +22,18 @@ from django.db.models.query import QuerySet
 
 
 manager_parent_classes = [Manager]
-commentsqueryset_parent_classes = [QuerySet]
+basequeryset_parent_classes = [QuerySet]
 
+# hack to change base class depending on if USE_GIS flag is enabled
 if settings.USE_GIS:
     from django.contrib.gis.db.models import GeoManager
     from django.contrib.gis.db.models.query import GeoQuerySet
     manager_parent_classes = [GeoManager]
-    commentsqueryset_parent_classes = [GeoQuerySet]
+    basequeryset_parent_classes = [GeoQuerySet]
 
 
 class ManagerMeta(type):
+    """ Metaclass which changes the parent classes depending on if USE_GIS flag is enabled """
 
     def __new__(meta, name, bases, dct):
         newbases = list(bases) + manager_parent_classes + [object]
@@ -39,24 +41,22 @@ class ManagerMeta(type):
         return type.__new__(meta, name, newbases, dct)
 
 
-class CommentsQuerySetMeta(type):
+class BaseQuerySetMeta(type):
+    """ Metaclass which changes the parent classes depending on if USE_GIS flag is enabled """
 
     def __new__(meta, name, bases, dct):
-        newbases = list(bases) + commentsqueryset_parent_classes + [object]
+        newbases = list(bases) + basequeryset_parent_classes + [object]
         newbases = tuple(newbases)
         return type.__new__(meta, name, newbases, dct)
 
 
 class BaseManager:
-    """ base manager for all content types """
+    """ Base manager for all Merengue content types """
     __metaclass__ = ManagerMeta
 
-    # XXX: for now we have no customization,
-    # but I think in future can be useful
-
 
 class WorkflowManager(BaseManager):
-    """ manager for all objects that have a workflow (a status field) """
+    """ Manager for all objects that have a workflow (a status field) """
 
     def by_status(self, status):
         return self.filter(status=status)
@@ -74,10 +74,29 @@ class WorkflowManager(BaseManager):
         return self.by_status('draft')
 
 
+class BaseContentQuerySet:
+    """ Base queryset class for all managed contents (which inherits BaseContent) """
+    __metaclass__ = BaseQuerySetMeta
+
+    def visible_by_user(self, user):
+        from merengue.perms.utils import has_permission
+        for content in self:
+            if has_permission(content, user, 'view'):
+                yield content
+
+    def editable_by_user(self, user):
+        from merengue.perms.utils import has_permission
+        for content in self:
+            if has_permission(content, user, 'edit'):
+                yield content
+
+
 class CommentsQuerySet:
-    __metaclass__ = CommentsQuerySetMeta
+    """ Base queryset class for comments """
+    __metaclass__ = BaseQuerySetMeta
 
     def with_comment_number(self, ordered_by_comment_number=False):
+        """ Add a useful extra attribute with the comments number """
         from django.contrib.contenttypes.models import ContentType
         from threadedcomments.models import FreeThreadedComment
         comments_table = connection.ops.quote_name(FreeThreadedComment._meta.db_table)
@@ -99,13 +118,20 @@ WHERE content_type_id = %%s and object_id = %s.basecontent_ptr_id and is_public"
 
 
 class CommentsManager(WorkflowManager):
+    """ Manager for all comments """
 
     def get_query_set(self):
         return CommentsQuerySet(self.model)
 
 
-class BaseContentManager(CommentsManager):
-    """ manager for all objects that inherits from BaseContent """
+class BaseContentManager(WorkflowManager):
+    """ Manager for all objects that inherits from BaseContent """
+
+    def get_query_set(self):
+        return BaseContentQuerySet(self.model)
+
+    def visible_by_user(self, user):
+        return self.get_query_set().visible_by_user(user)
 
     def different_class_names(self):
         """List with the different values for the attribute class_name"""
