@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 import base64
 import datetime
 import feedparser
@@ -18,7 +35,9 @@ from django.utils.translation import ugettext_lazy as _
 from transmeta import get_real_fieldname, fallback_language
 
 from merengue.base.models import BaseContent
+from merengue.section.models import BaseSection
 from merengue.collection import filter_funcs
+from merengue.collection.exceptions import CollectionWithoutContentTypesException
 
 
 FILTER_OPERATORS = (
@@ -35,7 +54,7 @@ FILTER_OPERATORS = (
     ('date_lt', _('Less than (for dates objects)')),
     ('gt', _('Greater than')),
     ('gte', _('Greater than or equal')),
-    ('date_gt', _('Grater than (for dates objects)')),
+    ('date_gt', _('Greater than (for dates objects)')),
     ('in', _('In (coma separated list)')),
     ('isnull', _('Is empty')),
 )
@@ -59,6 +78,8 @@ class Collection(BaseContent):
     content_types = models.ManyToManyField(
         ContentType,
         verbose_name=_(u'Content Types'),
+        blank=True,
+        null=True,
         )
 
     group_by = models.CharField(
@@ -75,17 +96,17 @@ class Collection(BaseContent):
         null=True,
         )
 
+    reverse_order = models.BooleanField(
+        default=False,
+        verbose_name=_(u'Reverse order'),
+        )
+
     limit = models.PositiveIntegerField(
         verbose_name=_(u'Number of elements '),
         blank=True,
         null=True,
         )
 
-    reverse_order = models.BooleanField(
-        default=False,
-        verbose_name=_(u'Reverse order'),
-        )
-
     show_main_image = models.BooleanField(
         default=True,
         verbose_name=_(u'Show main_image of collection items'),
@@ -101,7 +122,7 @@ class Collection(BaseContent):
         verbose_name = _(u'Collection')
         verbose_name_plural = _(u'Collections')
         content_view_function = 'merengue.collection.views.collection_view'
-        content_view_template = 'collection/collection_view.html'
+        content_view_template = 'collection_view.html'
 
     def get_exclude_filters(self):
         """@FIXME: Legacy code. Should be refactored"""
@@ -113,13 +134,17 @@ class Collection(BaseContent):
 
     def _get_items_from_one_source(self, ct):
         model = ct.model_class()
+        if not model:
+            return []
         query = model.objects.all()
         return self._filter_query(query)
 
     def _reduce_to_section(self, query, section=None):
         try:
-            if section:
+            if isinstance(section, BaseSection):
                 query = query.filter(sections=section)
+            elif isinstance(section, basestring):
+                query = query.filter(sections__slug=section)
         except FieldError:
             pass
         return query
@@ -149,14 +174,16 @@ class Collection(BaseContent):
         return self._filter_query(query)
 
     def get_items(self, section=None, filtering_section=None):
-        content_types = self.content_types.all()
-        if content_types.count() == 1:
+        content_types = list(self.content_types.all())
+        if len(content_types) == 1:
             items = self._get_items_from_one_source(content_types[0])
         else:
             for ct in content_types:
-                if not issubclass(ct.model_class(), BaseContent):
-                    items = self._get_items_from_multiple_sources( \
-                                                                content_types)
+                model = ct.model_class()
+                if not model:
+                    continue
+                if not issubclass(model, BaseContent):
+                    items = self._get_items_from_multiple_sources(content_types)
                     return items
             items = self._get_items_from_basecontent(content_types)
         if filtering_section is None:
@@ -169,13 +196,15 @@ class Collection(BaseContent):
         content_types = self.content_types.all()
         ct_len = len(content_types)
         if ct_len == 0:
-            return None
+            raise CollectionWithoutContentTypesException('The collection "%s" should have defined the content types to list' % self)
         elif ct_len == 1:
             return content_types[0].model_class()
-        parents_first = None
+        parents_first = []
         for i in range(ct_len - 1):
-            parents_first = parents_first or content_types[i].model_class().mro()
-            parents_second = content_types[i + 1].model_class().mro()
+            model = content_types[i].model_class()
+            next_model = content_types[i + 1].model_class()
+            parents_first = parents_first or (model and model.mro())
+            parents_second = (next_model and next_model.mro()) or []
             for i, parent_first in enumerate(parents_first):
                 if parent_first in parents_second:
                     parents_first = parents_first[i:]
@@ -264,7 +293,9 @@ class FeedItem(BaseContent):
 
     class Meta:
         content_view_function = 'merengue.collection.views.feeditem_view'
-        content_view_template = 'collection/feeditem_view.html'
+        content_view_template = 'feeditem_view.html'
+        verbose_name = _(u'Feed item')
+        verbose_name_plural = _(u'Feed items')
 
     def get_real_item(self):
         if hasattr(self, '_real_item'):
@@ -276,6 +307,14 @@ class FeedItem(BaseContent):
         self._real_item = real_item
         return real_item
 
+    def get_owners(self):
+        """
+        Override the default behavior. It does not use owners field because
+        the feed items are created automatically (have no owners). The owners
+        will be the same owners of the feed collection
+        """
+        return self.feed_collection.get_owners()
+
     def get_full_item(self, field_name=None):
         real_item = self.get_real_item()
         if hasattr(self, '_full_item'):
@@ -302,6 +341,27 @@ class FeedItem(BaseContent):
         parent_content_type = ContentType.objects.get_for_model(self.feed_collection)
         return ('merengue.base.views.admin_link', [parent_content_type.id, self.feed_collection.id, 'items/%s/' % self.id])
 
+    def get_parent_for_permissions(self):
+        return self.feed_collection.get_parent_for_permissions()
+
+    def get_main_section(self):
+        return self.feed_collection.get_main_section()
+
+    def breadcrumbs_items(self):
+        urls = []
+        try:
+            first_item = self.breadcrumbs_first_item()
+            if first_item:
+                urls.append(first_item)
+        except ImportError:
+            urls = []
+        urls.append((unicode(self.feed_collection),
+                     self.feed_collection.get_absolute_url()))
+        last_item = self.breadcrumbs_last_item()
+        if last_item:
+            urls.append(last_item)
+        return urls
+
 
 def handle_feed_item_pre_save(sender, instance, **kwargs):
     field_name = get_real_fieldname('name', fallback_language())
@@ -340,7 +400,7 @@ class FeedCollection(Collection):
     expire_seconds = models.IntegerField(
         verbose_name=_(u'Seconds to expire cache'),
         help_text=_(u'Seconds from last update to do a new query. 0 to never query again.'),
-        default=0,
+        default=86400,  # 24 hours
         )
 
     remove_items = models.BooleanField(
@@ -379,7 +439,7 @@ class FeedCollection(Collection):
         verbose_name = _(u'Feed collection')
         verbose_name_plural = _(u'Feed collections')
         content_view_function = 'merengue.collection.views.collection_view'
-        content_view_template = 'collection/collection_view.html'
+        content_view_template = 'collection_view.html'
 
     def perform_query(self, apply_options=False, force_update=False):
         now = datetime.datetime.now()
@@ -399,6 +459,9 @@ class FeedCollection(Collection):
         for item in self.feeditem_set.all():
             item.delete()
 
+    def get_first_parents_of_content_types(self):
+        return FeedItem
+
     def make_single_item(self, feed_item, entry):
         feed_item.item_cached = base64.encodestring(pickle.dumps(entry))
         if self.order_by:
@@ -436,10 +499,13 @@ class FeedCollection(Collection):
         for i in self.feeditem_set.exclude(item_id__in=entries_ids):
             item = i.get_real_item()
             self.make_single_item(i, item)
+        state_published = self.workflow_status.workflow.states.filter(slug='published')
         for entry in entries:
             (item, created) = FeedItem.objects.get_or_create(
                 item_id=entry.id,
                 feed_collection=self)
+            if created and state_published:
+                item.workflow_status = state_published[0]
             item.item_complete_cached = None  # Expire details of item if any
             self.make_single_item(item, entry)
 
@@ -611,6 +677,10 @@ class IncludeCollectionFilter(CollectionFilter):
         verbose_name=_(u'Collection'),
         )
 
+    class Meta:
+        verbose_name = _(u'Include collection filter')
+        verbose_name_plural = _(u'Include collection filters')
+
 
 class ExcludeCollectionFilter(CollectionFilter):
     collection = models.ForeignKey(
@@ -619,6 +689,10 @@ class ExcludeCollectionFilter(CollectionFilter):
         verbose_name=_(u'Collection'),
         )
 
+    class Meta:
+        verbose_name = _(u'Exclude collection filter')
+        verbose_name_plural = _(u'Exclude collection filters')
+
     def filter_query(self, query):
         custom_filter_method_name = '_filter_%s_query' % (self.filter_operator)
         if hasattr(self, custom_filter_method_name):
@@ -668,6 +742,10 @@ class CollectionDisplayField(models.Model):
         editable=False,
         )
 
+    class Meta:
+        verbose_name = _(u'Collection display field')
+        verbose_name_plural = _(u'Collection display fields')
+
     def __unicode__(self):
         return self.field_name
 
@@ -691,3 +769,7 @@ class CollectionDisplayFieldFilter(models.Model):
         default=0,
         verbose_name=_(u'Filter order'),
         )
+
+    class Meta:
+        verbose_name = _(u'Collection display field filter')
+        verbose_name_plural = _(u'Collection display field filters')
