@@ -1,5 +1,24 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
+from django.conf import settings
 from django.contrib import admin
 from django.contrib.admin.options import IncorrectLookupParameters
+from django.db.models import Q
 from django.forms.util import ErrorList
 from django.http import HttpResponseRedirect
 from django.shortcuts import render_to_response
@@ -7,17 +26,17 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ugettext
 
-#from batchadmin.util import model_ngettext
-
 from merengue.base.admin import (OrderableRelatedModelAdmin, BaseContentAdmin, BaseAdmin,
                                  WorkflowBatchActionProvider, RelatedModelAdmin)
 from merengue.base.models import BaseContent, MultimediaRelation
-from merengue.multimedia.forms import VideoCheckerModelForm
+from merengue.multimedia.forms import AudioCheckerModelForm, VideoCheckerModelForm
 from merengue.multimedia.models import (Photo, Video, PanoramicView, Image3D,
                                         File, Audio, BaseMultimedia)
+from merengue.perms import utils as perms_api
+from merengue.perms.exceptions import PermissionDenied
 
 
-class BaseMultimediaContentRelatedModelAdmin(BaseContentAdmin, RelatedModelAdmin):
+class BaseMultimediaContentRelatedModelAdmin(RelatedModelAdmin, BaseContentAdmin):
     list_filter = ('class_name', ) + BaseContentAdmin.list_filter
     inherit_actions = False
     related_field = 'multimediarelation'
@@ -31,25 +50,35 @@ class MultimediaAddContentRelatedModelAdmin(BaseMultimediaContentRelatedModelAdm
 
     def queryset(self, request):
         multimedia = self.basecontent
-        return BaseContent.objects.exclude(multimediarelation__multimedia=multimedia)
+        qs = BaseContent.objects.exclude(multimediarelation__multimedia=multimedia)
+        user = request.user
+        if not perms_api.can_manage_site(user) and\
+           not perms_api.has_global_permission(user, 'edit'):
+            owner_filter = Q(owners=request.user)
+            if settings.ACQUIRE_SECTION_ROLES:
+                owner_filter = owner_filter | Q(sections__owners=request.user)
+            qs = qs.filter(owner_filter)
+        return qs
 
     def associate_contents(self, request, queryset):
         selected = request.POST.getlist(admin.ACTION_CHECKBOX_NAME)
         if selected:
+            perms_api.assert_has_permission_in_queryset(queryset, request.user, 'edit')
+            if not self.has_change_permission(request):
+                raise PermissionDenied(user=request.user, perm='edit')
             if request.POST.get('post'):
-                if self.has_change_permission(request):
-                    multimedia = self.basecontent
-                    for content in queryset:
-                        mr = MultimediaRelation(content=content, multimedia=multimedia)
-                        mr.save(update_order=True)
-                        obj_log = ugettext(u"%(content)s content associated to %(multimedia)s") % {
-                            'content': content, 'multimedia': multimedia}
-                        self.log_change(request, content, obj_log)
-                    msg_data = {'number': len(queryset),
-                                'model_name': self.opts}
-                    msg = ugettext(u"Successfully associated %(number)d %(model_name)s.") % msg_data
-                    self.message_user(request, msg)
-                return # end action
+                multimedia = self.basecontent
+                for content in queryset:
+                    mr = MultimediaRelation(content=content, multimedia=multimedia)
+                    mr.save(update_order=True)
+                    obj_log = ugettext(u"%(content)s content associated to %(multimedia)s") % {
+                        'content': content, 'multimedia': multimedia}
+                    self.log_change(request, content, obj_log)
+                msg_data = {'number': len(queryset),
+                            'model_name': self.opts}
+                msg = ugettext(u"Successfully associated %(number)d %(model_name)s.") % msg_data
+                self.message_user(request, msg)
+                return  # end action
             extra_context = {'title': ugettext(u'Are you sure you want to associate these contents?'),
                              'action_submit': 'associate_contents'}
             return self.confirm_action(request, queryset, extra_context)
@@ -67,6 +96,9 @@ class MultimediaRemoveContentRelatedModelAdmin(BaseMultimediaContentRelatedModel
     def disassociate_contents(self, request, queryset):
         selected = request.POST.getlist(admin.ACTION_CHECKBOX_NAME)
         if selected:
+            perms_api.assert_has_permission_in_queryset(queryset, request.user, 'edit')
+            if not self.has_change_permission(request):
+                raise PermissionDenied(user=request.user, perm='edit')
             if request.POST.get('post'):
                 multimedia = self.basecontent
                 for content in queryset:
@@ -78,7 +110,7 @@ class MultimediaRemoveContentRelatedModelAdmin(BaseMultimediaContentRelatedModel
                                 'model_name': self.opts}
                 msg = ugettext(u"Successfully disassociated %(number)d %(model_name)s.") % msg_data
                 self.message_user(request, msg)
-                return # end action
+                return  # end action
             extra_context = {'title': ugettext('Are you sure you want disassociate this contents?'),
                              'action_submit': 'disassociate_contents'}
             return self.confirm_action(request, queryset, extra_context)
@@ -96,6 +128,24 @@ class BaseMultimediaAdmin(BaseAdmin, WorkflowBatchActionProvider):
              'multipleSeparator': " ",
              'size': 100}, }
 
+    def has_add_permission(self, request):
+        """
+            Overrides Django admin behaviour to add ownership based access control
+        """
+        return perms_api.can_manage_multimedia(request.user)
+
+    def has_change_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        return self.has_add_permission(request)
+
+    def has_delete_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        return self.has_add_permission(request)
+
     def change_view(self, request, object_id, extra_context=None):
         extra_context = extra_context or {}
         extra_context.update({'is_multimedia': True})
@@ -162,7 +212,7 @@ class PhotoAdmin(BaseMultimediaAdmin):
             qs = qs.filter(basecontent__class_name=class_name)
             get.pop('class_name')
             request.CLASS_NAME = class_name
-            request.GET=get
+            request.GET = get
         return qs
 
     def changelist_view(self, request, extra_context=None):
@@ -177,8 +227,8 @@ class PhotoAdmin(BaseMultimediaAdmin):
             return HttpResponseRedirect(request.path + '?' + ERROR_FLAG + '=1')
 
         class_name = getattr(request, 'CLASS_NAME', None)
-        cl.has_filters=True
-        class_names=[{'name': ugettext('All'), 'url': cl.get_query_string(remove='class_name')}]
+        cl.has_filters = True
+        class_names = [{'name': ugettext('All'), 'url': cl.get_query_string(remove='class_name')}]
         for i in BaseContent.objects.order_by('class_name').values('class_name').distinct():
             class_names.append({'name': i['class_name'],
                                 'url': cl.get_query_string(new_params={'class_name': i['class_name']})})
@@ -217,7 +267,6 @@ class Image3DAdmin(BaseMultimediaAdmin):
         def clean(self):
             super(form, self).clean()
             file_cleaned_data = self.cleaned_data.get('file', None)
-            url_cleaned_data = self.cleaned_data.get('external_url', None)
             old_file = obj and obj.file
             if not old_file and not file_cleaned_data:
                 global_errors = self.errors.get('__all__', ErrorList([]))
@@ -234,7 +283,11 @@ class Image3DAdmin(BaseMultimediaAdmin):
         return form
 
 
-class AudioAdmin(BaseMultimediaAdmin):
+class AudioChecker(object):
+    form = AudioCheckerModelForm
+
+
+class AudioAdmin(AudioChecker, BaseMultimediaAdmin):
     search_fields = ('name', 'original_filename')
     list_display = ('__str__', 'status', 'last_editor')
 
@@ -244,10 +297,11 @@ class RelatedBaseMultimediaAdmin(OrderableRelatedModelAdmin):
     search_fields = ('name', 'original_filename')
     list_display = ('__str__', 'status', 'last_editor')
     related_field = 'basecontent'
+    manage_contents = True
 
     def custom_relate_content(self, request, obj, form, change):
         if not change:
-            multimedia_rel = MultimediaRelation.objects.create(content=self.basecontent,
+            MultimediaRelation.objects.create(content=self.basecontent,
                 multimedia=obj.basemultimedia_ptr)
 
     def get_relation_obj(self, through_model, obj):
@@ -282,25 +336,21 @@ class RelatedFileAdmin(RelatedBaseMultimediaAdmin):
     tool_label = _('files')
 
 
-class RelatedAudioAdmin(RelatedBaseMultimediaAdmin):
+class RelatedAudioAdmin(AudioChecker, RelatedBaseMultimediaAdmin):
     tool_name = 'audios'
     tool_label = _('audio files')
 
 
 def register(site):
-    site.register(Photo, PhotoAdmin)
-    site.register(Video, VideoAdmin)
-    site.register(PanoramicView, PanoramicViewAdmin)
-    site.register(Image3D, Image3DAdmin)
-    site.register(Audio, AudioAdmin)
     register_related_multimedia(site, BaseContent)
 
 
 def register_related_multimedia(site, related_to):
     site.register_related(Photo, RelatedPhotoAdmin, related_to=related_to)
     site.register_related(Video, RelatedVideoAdmin, related_to=related_to)
-    site.register_related(PanoramicView, RelatedPanoramicViewAdmin, related_to=related_to)
-    site.register_related(Image3D, RelatedImage3DAdmin, related_to=related_to)
+    # PanoramicView and Image3D are not fully implemented, so we hide them
+    #site.register_related(PanoramicView, RelatedPanoramicViewAdmin, related_to=related_to)
+    #site.register_related(Image3D, RelatedImage3DAdmin, related_to=related_to)
     site.register_related(File, RelatedFileAdmin, related_to=related_to)
     site.register_related(Audio, RelatedAudioAdmin, related_to=related_to)
 
