@@ -17,14 +17,15 @@
 
 import os
 
+from django.conf import settings
+from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
+from django.core.exceptions import ObjectDoesNotExist, SuspiciousOperation
+from django.core.files.uploadedfile import UploadedFile
 from django.db import models
 from django.db.models import signals, permalink
-from django.conf import settings
+from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
-from django.core.files.uploadedfile import UploadedFile
-from django.core.exceptions import ObjectDoesNotExist, SuspiciousOperation
-from django.contrib.auth.models import User
 
 from south.modelsinspector import add_introspection_rules
 from stdimage import StdImageField
@@ -33,6 +34,7 @@ from transmeta import TransMeta
 import sorl
 
 from merengue.base.managers import WorkflowManager
+from merengue.base.utils import get_translate_status_list
 from merengue.multimedia.managers import MultimediaManager
 from merengue.multimedia.fields import VideoField
 
@@ -62,10 +64,10 @@ class BaseMultimedia(models.Model):
                                   max_length=100, db_index=True,
                                   editable=False, null=True)
 
-    status = models.CharField(_('Publication status'), max_length=20, choices=settings.STATUS_LIST,
+    status = models.CharField(_('Publication status'), max_length=20, choices=get_translate_status_list(),
                               default='draft', help_text=_('Enter the current status'), db_index=True,
                               editable=True)
-    last_editor = models.ForeignKey(User, null=True, blank=True, editable=False)
+    last_editor = models.ForeignKey(User, verbose_name=_('last editor'), null=True, blank=True, editable=False)
     authors = models.CharField(verbose_name=_('authors'), max_length=200,
                                null=True, blank=True)
 
@@ -207,9 +209,8 @@ class Photo(BaseMultimedia):
         # wether we are adding or modifying an image, the tumbnails are no longer valid.
         # delete it from the image and all its basecontent related items.
         sorl.thumbnail.delete(self.image, delete_file=False)
-        if self.id:
-            for bc in self.basecontent_set.filter(main_image__isnull=False):
-                sorl.thumbnail.delete(bc.main_image, delete_file=False)
+        # Just in case someone tries to do a sorl thumbnail of the StdImage thumbnail
+        sorl.thumbnail.delete(self.image.thumbnail, delete_file=False)
 
 #@FIXME: Duplicate code. base/models.py line 219
     def admin_thumbnail(self):
@@ -246,10 +247,9 @@ class Video(BaseMultimedia):
                             upload_to=VIDEO_MEDIA_PREFIX,
                             thumbnail_size=(200, 200),
                             blank=True, null=True)
-    external_url = models.URLField(verify_exists=False,
-                                   verbose_name=_('external url'),
-                                   help_text=_('The url of one video from youtube or google-video'),
-                                   blank=True, null=True, max_length=255)
+    external_url = models.CharField(verbose_name=_('external url'),
+                                     help_text=_('The url of one video from youtube or google-video'),
+                                     blank=True, null=True, max_length=255)
     # only for migration purposes
     plone_uid = models.CharField(verbose_name=_('plone uid'),
                                  max_length=100, db_index=True,
@@ -263,6 +263,18 @@ class Video(BaseMultimedia):
         self._save_original_filename(self.file)
         super(Video, self).save(**kwargs)
 
+    def get_absolute_url(self):
+        if self.file:
+            return self.file.url
+        return self.external_url
+
+    def get_configure(self):
+        from merengue.theming.models import Theme
+        return render_to_string('multimedia/video.js',
+                                {'video_info': self,
+                                 'MEDIA_URL': settings.MEDIA_URL,
+                                 'THEME_MEDIA_URL': Theme.objects.active().get_theme_media_url()})
+
 #@FIXME: Duplicate code. line 292
     def admin_thumbnail(self):
         if self.preview:
@@ -359,6 +371,18 @@ class Audio(BaseMultimedia):
         verbose_name = _('audio file')
         verbose_name_plural = _('audio files')
 
+    def get_absolute_url(self):
+        if self.file:
+            return self.file.url
+        return ''
+
+    def get_configure(self):
+        from merengue.theming.models import Theme
+        return render_to_string('multimedia/audio.js',
+                                {'audio_info': self,
+                                 'MEDIA_URL': settings.MEDIA_URL,
+                                 'THEME_MEDIA_URL': Theme.objects.active().get_theme_media_url()})
+
     def save(self, **kwargs):
         self._save_original_filename(self.file)
         super(Audio, self).save(**kwargs)
