@@ -27,7 +27,8 @@ except ImportError:
 from django import templatetags
 from django.conf import settings
 from django.conf.urls.defaults import include, url
-from django.contrib.admin.sites import NotRegistered
+from django.contrib.admin.sites import NotRegistered, AlreadyRegistered
+from django.contrib.contenttypes.management import update_all_contenttypes
 from django.core.exceptions import ImproperlyConfigured, FieldError, MiddlewareNotUsed
 from django.core.management import call_command
 from django.core.management.color import no_style
@@ -38,12 +39,14 @@ from django.db import connection, transaction
 from django.db.models import get_models
 from django.db.models.loading import load_app, cache
 from django.utils.importlib import import_module
+from django.utils.translation import get_language, activate
 
 from south import migration
 from south.exceptions import NoMigrations
 
 from merengue import registry
 from merengue.base.adminsite import site
+from merengue.block.utils import clear_lookup_cache
 from merengue.registry.items import (NotRegistered as NotRegisteredItem)
 from merengue.section.models import BaseSection
 from merengue.section.middleware import register_section_prefix, unregister_section_prefix
@@ -54,7 +57,6 @@ from merengue.pluggable.models import RegisteredPlugin
 
 # ----- internal attributes and methods -----
 
-
 _plugin_middlewares_cache = {
     'loaded_middlewares': [],
     'request_middleware': [],
@@ -64,6 +66,10 @@ _plugin_middlewares_cache = {
 }
 
 
+def _get_url_resolver():
+    return urlresolvers.get_resolver(import_module(urlresolvers.get_urlconf(settings.ROOT_URLCONF)))
+
+
 # ----- public methods -----
 
 
@@ -73,6 +79,7 @@ def install_plugin(registered_plugin):
     # Needed update installed apps in order
     # to get SQL command from merengue.pluggable
     add_to_installed_apps(plugin_name)
+    clear_plugin_module_cache(plugin_name)
     if load_app(plugin_name) and not are_installed_models(app_name):
         install_models(app_name)
         reload_models_cache()
@@ -121,7 +128,7 @@ def get_plugin_config(plugin_dir, prepend_plugins_dir=True):
 
 def get_plugin(plugin_dir, prepend_plugins_dir=True):
     plugin_config = get_plugin_config(plugin_dir, prepend_plugins_dir)
-    reg_plugin = RegisteredPlugin.objects.by_item_class(plugin_config).get()
+    reg_plugin = RegisteredPlugin.objects.get_by_item_class(plugin_config)
     return reg_plugin.get_registry_item()
 
 
@@ -155,13 +162,22 @@ def are_installed_models(app_name):
 def install_models(app_name):
     app_module = load_app(get_plugin_module_name(app_name))
     if have_south(app_name):
+        lang = get_language()
+        # invalidate south cache to avoid very weird bugs (see #2025)
+        migration.Migrations.invalidate_all_modules()
+        migration.Migrations.calculate_dependencies(force=True)
+        # migrate plugin with south
         call_command('migrate', app=app_name)
+        # call_command activates a default 'en-us' locale in thread. we restore it
+        activate(lang)
     else:
         style = no_style()
         cursor = connection.cursor()
-        sql_commands = sql_all(app_module, style)
+        sql_commands = sql_all(app_module, style, connection)
         for sql_command in sql_commands:
             cursor.execute(sql_command)
+    # update all content types
+    update_all_contenttypes()
     transaction.commit()
 
 
@@ -208,10 +224,10 @@ def find_plugin_urls(plugin_name):
 def check_plugin_broken(plugin_name):
     """ Check if plugin is broken (i.e. not exist in file system) and raises an exception """
     try:
-        get_plugin_config(plugin_name, prepend_plugins_dir=False)
+        get_plugin_config(plugin_name)
         try:
             # try to import plugin modules (if exists) to validate those models
-            models_modname = '%s.models' % plugin_name
+            models_modname = '%s.models' % get_plugin_module_name(plugin_name)
             models_module = import_module(models_modname)
             s = StringIO()
             num_errors = get_validation_errors(s, models_module)
@@ -240,6 +256,7 @@ def enable_plugin(plugin_name, register=True):
         register_plugin_viewlets(plugin_name)
         register_plugin_templatetags(plugin_name)
         register_plugin_post_actions(plugin_name)
+        register_plugin_models(plugin_name)
         register_plugin_section_models(plugin_name)
         register_plugin_in_plugin_admin_site(plugin_name)
         register_plugin_perms(plugin_name)
@@ -267,6 +284,7 @@ def disable_plugin(plugin_name, unregister=True):
         unregister_plugin_middlewares(plugin_name)
         unregister_plugin_viewlets(plugin_name)
         unregister_plugin_templatetags(plugin_name)
+        unregister_plugin_models(plugin_name)
         unregister_plugin_section_models(plugin_name)
         unregister_plugin_in_plugin_admin_site(plugin_name)
         unregister_plugin_perms(plugin_name)
@@ -282,27 +300,47 @@ def disable_plugin(plugin_name, unregister=True):
 def register_plugin_urls(plugin_name):
     for index, plugin_url in find_plugin_urls(plugin_name):
         if plugin_url and index < 0:
-            proj_urls = import_module(settings.ROOT_URLCONF)
-            proj_urls.urlpatterns += (plugin_url, )
+            urlpatterns = _get_url_resolver().url_patterns
+            urlpatterns += (plugin_url, )
     update_admin_urls()
+    urlresolvers.clear_url_caches()
 
 
-def unregister_plugin_urls(plugin_name):
+def unregister_urlpattern(urlpattern, urlpatterns_list):
+    urlpatterns_to_recurse = []
+    for i, child_pattern in enumerate(urlpatterns_list):
+        if hasattr(child_pattern, 'urlconf_module') and child_pattern.urlconf_module == urlpattern.urlconf_module:
+            del urlpatterns_list[i]  # unregister URL pattern
+            return
+        if isinstance(child_pattern, urlresolvers.RegexURLResolver):
+            urlpatterns_to_recurse.append(child_pattern.url_patterns)
+    for child_url in urlpatterns_to_recurse:
+        unregister_urlpattern(urlpattern, child_url)
+
+
+def unregister_plugin_urls(plugin_name, urlpatterns=None):
+    if urlpatterns is None:
+        urlpatterns = _get_url_resolver().url_patterns
     for index, plugin_url in find_plugin_urls(plugin_name):
         if index > 0:
-            proj_urls = import_module(settings.ROOT_URLCONF)
-            del proj_urls.urlpatterns[index]
+            unregister_urlpattern(plugin_url, urlpatterns)
     update_admin_urls()
 
 
-def update_admin_urls():
+def update_admin_urls(urlresolver=None):
     from merengue.base import admin
-    urlconf = import_module(settings.ROOT_URLCONF)
-    url_patterns = urlconf.urlpatterns
-    for i, url_pattern in enumerate(url_patterns):
-        if getattr(url_pattern, 'app_name', '') == 'admin':
-            urlresolvers.clear_url_caches()
-            urlconf.urlpatterns[i] = url(r'^admin/', include(admin.site.urls))
+    if urlresolver is None:
+        urlresolver = _get_url_resolver()
+    for i, child_pattern in enumerate(urlresolver.url_patterns):
+        if isinstance(child_pattern, urlresolvers.RegexURLResolver):
+            if child_pattern.app_name == 'admin':
+                urlresolver.url_patterns[i] = url(r'^admin/', include(admin.site.urls))
+                return
+            else:
+                # does the recursion to find "admin" app in the child
+                # with debug toolbar the admin is not in root urlconf
+                update_admin_urls(child_pattern)
+                child_pattern._populate()  # invalidate to allow reverse resolution
 
 
 def register_plugin_templatetags(plugin_name):
@@ -326,7 +364,7 @@ def unregister_plugin_templatetags(plugin_name):
 def register_items(item_list):
     for item_class in item_list:
         if not registry.have_registered_items(item_class):
-            registry.register(item_class, activate=True)
+            registry.register(item_class)
 
 
 def unregister_items(item_list):
@@ -355,14 +393,20 @@ def register_plugin_blocks(plugin_name):
     plugin = get_plugin(plugin_name, prepend_plugins_dir=False)
     if not plugin:
         return
-    register_items(plugin.get_blocks())
+    plugin_blocks = plugin.get_blocks()
+    if plugin_blocks:
+        register_items(plugin_blocks)
+        clear_lookup_cache()
 
 
 def unregister_plugin_blocks(plugin_name):
     plugin = get_plugin(plugin_name, prepend_plugins_dir=False)
     if not plugin:
         return
-    unregister_items(plugin.get_blocks())
+    plugin_blocks = plugin.get_blocks()
+    if plugin_blocks:
+        unregister_items(plugin_blocks)
+        clear_lookup_cache()
 
 
 def register_plugin_viewlets(plugin_name):
@@ -400,6 +444,17 @@ def register_plugin_post_actions(plugin_name):
     plugin.post_actions()
 
 
+def register_plugin_models(plugin_name):
+    plugin = get_plugin(plugin_name, prepend_plugins_dir=False)
+    if not plugin:
+        return
+    for model, model_admin in plugin.models():
+        try:
+            site.register_model(model, model_admin)
+        except AlreadyRegistered:
+            pass
+
+
 def register_plugin_section_models(plugin_name):
     plugin = get_plugin(plugin_name, prepend_plugins_dir=False)
     if not plugin:
@@ -407,6 +462,14 @@ def register_plugin_section_models(plugin_name):
     register_plugin_section_models_in_admin_site(plugin, plugin_name, site)
 
 
+def unregister_plugin_models(plugin_name):
+    plugin = get_plugin(plugin_name, prepend_plugins_dir=False)
+    if not plugin:
+        return
+    for model, model_admin in plugin.models():
+        site.unregister_model(model)
+
+
 def unregister_plugin_section_models(plugin_name):
     pass
 
@@ -415,8 +478,11 @@ def register_plugin_section_models_in_admin_site(plugin, plugin_name, admin_site
     if not admin_site:
         return
     for model, admin_model in plugin.section_models():
-        site_related = admin_site.register_related(model, admin_model, related_to=BaseSection)
-        plugin.section_register_hook(site_related, model)
+        try:
+            site_related = admin_site.register_related(model, admin_model, related_to=BaseSection)
+            plugin.section_register_hook(site_related, model)
+        except AlreadyRegistered:
+            pass
 
 
 def register_plugin_in_plugin_admin_site(plugin_name):
@@ -428,7 +494,10 @@ def register_plugin_in_plugin_admin_site(plugin_name):
         return
     plugin_site = site.register_plugin_site(plugin_name)
     for model, admin_model in plugin.get_model_admins():
-        plugin_site.register(model, admin_model)
+        try:
+            plugin_site.register(model, admin_model)
+        except AlreadyRegistered:
+            pass
 
 
 def unregister_plugin_in_plugin_admin_site(plugin_name):
@@ -495,15 +564,21 @@ def reload_models_cache():
     Reload Django internal cache for all models in installed apps.
     This includes model field mapping, related fields in _meta object, etc.
     """
+    installed_app_names = [app.split('.')[-1] for app in settings.INSTALLED_APPS]
+    for app_label in cache.app_models:
+        if app_label not in installed_app_names:
+            del cache.app_models[app_label]
     cache.loaded = False
     cache.handled = {}
     cache.app_store.clear()
     cache._populate()
+    cache._get_models_cache.clear()
     for model in get_models():
         opts = model._meta
         if hasattr(opts, '_related_many_to_many_cache'):
-            # we remove related m2m fields cache for all models
+            # we remove related m2m and fk fields cache for all models
             del opts._related_many_to_many_cache
+            del opts._related_objects_cache
         opts.init_name_map()
 
 
@@ -518,7 +593,7 @@ def reload_app_directories_template_loader():
         return
     for func in loader.template_source_loaders:
         module = func.__module__
-        attr = func.__name__
+        attr = func.__class__.__name__
         template_loader_name = "%s.%s" % (module, attr)
         if template_loader_app_directories == template_loader_name:
             try:
@@ -628,5 +703,29 @@ def get_plugins_middleware_methods(midd_type):
     return (t[1] for t in _plugin_middlewares_cache[midd_type])
 
 
+def register_dummy_plugin(plugin_name):
+    """ Register a dummy plugin. Useful when we cannot access to the PluginConfig """
+    try:
+        registered_plugin = RegisteredPlugin.objects.get(
+            directory_name=plugin_name,
+        )
+    except RegisteredPlugin.DoesNotExist:
+        registered_plugin = RegisteredPlugin.objects.create(
+            directory_name=plugin_name, broken=True,  # it's important to create with broken=True
+        )
+    registered_plugin.broken = True
+    registered_plugin.class_name = 'PluginConfig'
+    registered_plugin.module = '%s.%s.config' % (settings.PLUGINS_DIR, plugin_name)
+    registered_plugin.name = plugin_name
+    registered_plugin.save()
+    return registered_plugin
+
+
+def clear_plugin_module_cache(plugin_module):
+    for module_name, module in sys.modules.items():
+        if module_name.startswith(plugin_module) and 'migrations' not in module_name:
+            del sys.modules[module_name]
+
+
 from merengue.section.admin import register as register_section
 register_section(site)
