@@ -17,8 +17,23 @@
 
 from django.conf import settings
 from django.core.cache import cache
+from django.core.exceptions import PermissionDenied
 from django.http import Http404
 
+from merengue.middleware import HttpStatusCode403Provider
+
+_section_prefixes = []
+
+
+def register_section_prefix(section_prefix):
+    if section_prefix not in _section_prefixes:
+        _section_prefixes.append(section_prefix)
+
+
+def unregister_section_prefix(section_prefix):
+    if section_prefix in _section_prefixes:
+        _section_prefixes.remove(section_prefix)
+
 
 class RequestSectionMiddleware(object):
     """This middleware autodiscovers the current section from the url"""
@@ -27,26 +42,21 @@ class RequestSectionMiddleware(object):
         from merengue.section.models import BaseSection
 
         section = None
-        if request.path:
-            path_list = request.path.split('/')
-            if path_list[1] == settings.MERENGUE_URLS_PREFIX and path_list[2] == 'sections':
-                section_position = 3
-            elif path_list[1] == 'sections':
-                section_position = 2
-            else:
-                section_position = 1
-            section_path = path_list[section_position]
-            slugs_cache_key = 'section_slugs'
-            section_slugs = cache.get(slugs_cache_key)
-            if section_slugs is None:
-                section_slugs = [v[0] for v in BaseSection.objects.all().values_list('slug')]
-                cache.set(slugs_cache_key, section_slugs)
-            if section_path in section_slugs:
+        if request.path and not request.path.startswith(settings.MEDIA_URL):
+            matched_prefix = None
+            for section_prefix in _section_prefixes + ['/', ]:
+                if request.path.startswith(section_prefix):
+                    matched_prefix = section_prefix
+                    break
+            if matched_prefix:
+                section_path = request.path[len(matched_prefix):]
+                next_slash_index = section_path.find('/')
+                section_slug = section_path[:next_slash_index]
                 try:
-                    cache_key = 'app_section_%s' % section_path
+                    cache_key = 'section_%s' % section_slug
                     section = cache.get(cache_key)
                     if section is None:
-                        section = BaseSection.objects.get(slug=section_path)
+                        section = BaseSection.objects.get(slug=section_slug)
                         cache.set(cache_key, section)
                 except:
                     # we put an blank except because some times in WSGI in a heavy loaded environments
@@ -55,19 +65,21 @@ class RequestSectionMiddleware(object):
         request.section = section
 
 
-class ResponseSectionMiddleware(object):
+class ResponseSectionMiddleware(HttpStatusCode403Provider):
     """This middleware autodiscovers the current section from the url"""
 
     def process_response(self, request, response):
         from merengue.section.views import section_dispatcher
         if response.status_code != 404:
-            return response # No need to check for a section for non-404 responses.
+            return response  # No need to check for a section for non-404 responses.
         try:
             return section_dispatcher(request, request.path_info)
         # Return the original response if any errors happened. Because this
         # is a middleware, we can't assume the errors will be caught elsewhere.
         except Http404:
             return response
+        except PermissionDenied, exception:
+            return self.process_exception(request, exception)
         except:
             if settings.DEBUG:
                 raise
