@@ -19,7 +19,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.urlresolvers import reverse
 from django.db import models
-from django.db.models import permalink
+from django.db.models import permalink, Q
 from django.db.models.signals import post_save
 from django.template import defaultfilters
 from django.template.loader import render_to_string
@@ -29,11 +29,22 @@ import mptt
 
 from merengue.base.managers import WorkflowManager
 from merengue.base.models import BaseContent
+from merengue.cache import memoize, MemoizeCache
 from merengue.section.managers import SectionManager
+from merengue.perms.models import Role
+from merengue.perms import utils as perms_api
 from merengue.viewlet.models import RegisteredViewlet
 from transmeta import TransMeta, get_fallback_fieldname
 
 
+_menu_sections_cache = MemoizeCache('menu_sections')
+
+
+def _convert_cache_args(mem_args):
+    item_class = mem_args[0]
+    return item_class.pk
+
+
 class RealInstanceMixin(object):
 
     check_attributes = tuple()
@@ -89,6 +100,14 @@ class Menu(models.Model):
         null=False,
         )
 
+    help_text = models.CharField(
+        verbose_name=_('help text'),
+        help_text=_('text for describing the menu target, usually placed as link title attribute'),
+        max_length=200,
+        blank=True,
+        null=True,
+        )
+
     parent = models.ForeignKey('Menu',
         verbose_name=_('Parent'),
         blank=True,
@@ -103,10 +122,27 @@ class Menu(models.Model):
         editable=False,
         )
 
+    status = models.CharField(
+        verbose_name=_('status'),
+        help_text=_('status of the menu element'),
+        choices=(('public', _('public')), ('draft', _('draft'))),
+        default='public',
+        max_length=25,
+    )
+
+    visible_by_roles = models.ManyToManyField(
+        Role,
+        related_name='visible_menus',
+        verbose_name=_('visible menus'),
+        blank=True,
+        null=True,
+        help_text=_('The roles that will see this menu')
+    )
+
     class Meta:
         verbose_name = _('menu')
         verbose_name_plural = _('menus')
-        translate = ('name', )
+        translate = ('name', 'help_text', )
 
     def __unicode__(self):
         return unicode(self.name)
@@ -116,6 +152,19 @@ class Menu(models.Model):
             self.update_url()
         return self.url
 
+    @permalink
+    def get_admin_absolute_url(self):
+        """ Link to the admin page for editing the object """
+        section = self.get_section()
+        if section:
+            section_content_type = ContentType.objects.get_for_model(section)
+            return ('merengue.base.views.admin_link', [section_content_type.id, section.id, 'mainmenu/%s/' % self.id])
+        else:
+            menu_content_type = ContentType.objects.get_for_model(self)
+            print menu_content_type.id
+            print self.id
+            return ('merengue.base.views.admin_link', [menu_content_type.id, self.id, ''])
+
     @permalink
     def menu_public_link_with_out_section(self, ancestors_path):
         return self._menu_public_link_without_section(self, ancestors_path)
@@ -148,7 +197,7 @@ class Menu(models.Model):
         except BaseLink.DoesNotExist:
             return True
 
-    def get_section(self):
+    def _get_section(self):
         try:
             return getattr(self, 'main_menu_section')
         except BaseSection.DoesNotExist:
@@ -156,6 +205,7 @@ class Menu(models.Model):
 
         if self.parent is not None:
             return self.parent.get_section()
+    get_section = memoize(_get_section, _menu_sections_cache, 1, convert_args_func=_convert_cache_args)
 
     def get_breadcrumbs(self):
         """ Menu breadcrumbs (not included itself) """
@@ -169,6 +219,38 @@ class Menu(models.Model):
             bc.insert(0, (section.get_absolute_url(), unicode(section)))
         return bc
 
+    def get_ancestors_by_user(self, user=None):
+        from merengue.perms.utils import can_manage_site
+        ancestors = self.get_ancestors().filter(status='public')  # uses mptt function
+        if user and not can_manage_site(user):
+            if not user.is_anonymous():
+                roles = Role.objects.filter(principalrolerelation__user=user)
+            else:
+                roles = Role.objects.filter(slug='anonymous_user')
+            ancestors = ancestors.filter(Q(visible_by_roles__isnull=True) |
+                                         Q(visible_by_roles__in=roles))
+        return ancestors
+
+    def get_descendants_by_user(self, user=None):
+        from merengue.perms.utils import can_manage_site
+        descendants = self.get_descendants().filter(status='public')  # uses mptt function
+        if user and not can_manage_site(user):
+            if not user.is_anonymous():
+                roles = Role.objects.filter(principalrolerelation__user=user)
+            else:
+                roles = Role.objects.filter(slug='anonymous_user')
+            descendants = descendants.filter(Q(visible_by_roles__isnull=True) |
+                                             Q(visible_by_roles__in=roles)).distinct()
+        return descendants
+
+    def can_edit(self, user):
+        section = self.get_section()
+        if section:
+            return section.can_edit(user)
+        else:
+            return perms_api.can_manage_site(user)
+
+
 try:
     mptt.register(Menu)
 except mptt.AlreadyRegistered:
@@ -229,7 +311,10 @@ class AbsoluteLink(BaseLink):
 
 class ContentLink(BaseLink):
 
-    content = models.ForeignKey(BaseContent, verbose_name=_('Content'))
+    content = models.ForeignKey(
+        BaseContent,
+        verbose_name=_('Content'),
+    )
 
     def get_absolute_url(self):
         assert self.content is not None
@@ -276,8 +361,8 @@ class BaseSection(BaseContent):
         verbose_name=_('main content'),
         help_text=_('content selected here will be shown when entering the section'),
         related_name='section_main_content',
+        on_delete=models.SET_NULL,
     )
-    main_content.delete_cascade = False
 
     related_content = models.ManyToManyField(
         BaseContent,
@@ -293,18 +378,24 @@ class BaseSection(BaseContent):
         blank=True,
         editable=False,
         verbose_name=_('custom style'),
+        on_delete=models.SET_NULL,
     )
-    customstyle.delete_cascade = False
 
     objects = SectionManager()
 
     class Meta:
         ordering = ('order', )
         verbose_name = _('section')
+        verbose_name_plural = _('sections')
+        check_slug_uniqueness = True
 
     def __unicode__(self):
         return unicode(self.name)
 
+    def get_parent_for_permissions(self):
+        """ The section has not parents. Returns None to avoid execute a uneeded SQL """
+        return None
+
     @property
     def check_attributes(self):
         return [subcl._meta.module_name for subcl in self.__class__.__subclasses__()]
@@ -386,12 +477,6 @@ class SectionRelatedContent(models.Model):
 
 class Document(BaseContent):
 
-    permanent = models.BooleanField(verbose_name=_('permanent'),
-                                    help_text=_('make this document not erasable and its slug ummutable'),
-                                    editable=False,
-                                    default=False,
-    )
-
     objects = WorkflowManager()
 
     class Meta:
@@ -502,17 +587,25 @@ class CustomStyle(models.Model):
         blank=True,
     )
 
+    class Meta:
+        verbose_name = _('custom sytle')
+        verbose_name_plural = _('custom styles')
+
 
 class CustomStyleImage(models.Model):
     customstyle = models.ForeignKey(CustomStyle)
 
     custom_css_image = models.ImageField(
-        verbose_name=('Custom CSS image'),
+        verbose_name=_('Custom CSS image'),
         upload_to='section_images',
         null=True,
         blank=True,
     )
 
+    class Meta:
+        verbose_name = _('custom sytle image')
+        verbose_name_plural = _('custom style images')
+
 
 def create_menus(sender, **kwargs):
     if issubclass(sender, BaseSection):
@@ -523,7 +616,7 @@ def create_menus(sender, **kwargs):
             menu_name = 'Main menu of %s' % unicode(instance)
             instance.main_menu = Menu.objects.create(**{'slug': defaultfilters.slugify(menu_name),
                                                         get_fallback_fieldname('name'): menu_name})
-            from merengue.utils import invalidate_johnny_cache
+            from merengue.cache import invalidate_johnny_cache
             invalidate_johnny_cache(instance.__class__, True, BaseSection)
             instance.save()
 
