@@ -19,7 +19,7 @@ from django.conf import settings
 from django.utils.translation import ugettext
 from django.utils.translation import ugettext_lazy as _
 
-from merengue.block.blocks import Block, ContentBlock
+from merengue.block.blocks import Block, ContentBlock, BaseBlock
 from merengue.registry import params
 from merengue.section.models import BaseSection, Menu
 from merengue.section.utils import get_section
@@ -29,9 +29,17 @@ from announcements.models import current_announcements_for_request
 
 class BaseMenuBlock(object):
 
-    config_params = [
+    config_params = BaseBlock.config_params + [
         params.Integer(name='max_num_level',
                        label=_('maximum number of levels to show'), default=-1)]
+    default_caching_params = {
+        'enabled': False,
+        'only_anonymous': True,
+        'vary_on_user': False,
+        'timeout': 3600,
+        'vary_on_url': True,
+        'vary_on_language': True,
+    }
 
     def get_max_level(self):
         max_value = self.get_config().get('max_num_level', None)
@@ -40,7 +48,20 @@ class BaseMenuBlock(object):
         return -1
 
 
-class CoreMenuBlock(BaseMenuBlock, Block):
+class BaseSingleMenuBlock(BaseMenuBlock):
+
+    config_params = BaseMenuBlock.config_params + [
+        params.Integer(name='max_num_items',
+                       label=_('maximum number of items without js collapsible'), default=-1)]
+
+    def get_max_num_items(self):
+        max_num_items = self.get_config().get('max_num_items', None)
+        if max_num_items:
+            return max_num_items.get_value()
+        return -1
+
+
+class CoreMenuBlock(BaseSingleMenuBlock, Block):
     name = 'coremenu'
     default_place = 'leftsidebar'
     help_text = _('Renders the Menu')
@@ -53,7 +74,7 @@ class CoreMenuBlock(BaseMenuBlock, Block):
         main_menu = section.main_menu
         descendants = None
         if main_menu is not None:
-            descendants = main_menu.get_descendants()
+            descendants = main_menu.get_descendants_by_user(request.user)
         if not section or not descendants:
             return ''  # renders nothing
         return self.render_block(request, template_name='core/block_menu.html',
@@ -61,7 +82,8 @@ class CoreMenuBlock(BaseMenuBlock, Block):
                                  context={'section': section,
                                           'menu': main_menu,
                                           'descendants': descendants,
-                                          'max_num_level': self.get_max_level()})
+                                          'max_num_level': self.get_max_level(),
+                                          'max_num_items': self.get_max_num_items()})
 
 
 class NavigationBlock(BaseMenuBlock, Block):
@@ -69,6 +91,14 @@ class NavigationBlock(BaseMenuBlock, Block):
     default_place = 'leftsidebar'
     help_text = _('Renders the Navigation')
     verbose_name = _('Navigation Block')
+    default_caching_params = {
+        'enabled': False,
+        'only_anonymous': True,
+        'vary_on_user': False,
+        'timeout': 3600,
+        'vary_on_url': True,
+        'vary_on_language': True,
+    }
 
     def render(self, request, place, context, *args, **kwargs):
         sections = BaseSection.objects.published()
@@ -82,7 +112,7 @@ class NavigationBlock(BaseMenuBlock, Block):
                                           'max_num_level': self.get_max_level()})
 
 
-class PortalMenuBlock(BaseMenuBlock, Block):
+class PortalMenuBlock(BaseSingleMenuBlock, Block):
     name = 'portalmenu'
     default_place = 'header'
     help_text = _('Renders the Portal Menu')
@@ -93,7 +123,8 @@ class PortalMenuBlock(BaseMenuBlock, Block):
         return self.render_block(request, template_name='core/block_portal_menu.html',
                                  block_title=ugettext('Portal Menu'),
                                  context={'portal_menu': portal_menu,
-                                          'max_num_level': self.get_max_level()})
+                                          'max_num_level': self.get_max_level(),
+                                          'max_num_items': self.get_max_num_items()})
 
 
 class LinkBaseBlock(Block):
@@ -102,33 +133,47 @@ class LinkBaseBlock(Block):
     template_name = 'core/block_portallinks.html'
     help_text = _('Abstract block that render portal links')
     verbose_name = _('Link Base Block')
+    default_caching_params = {
+        'enabled': False,
+        'only_anonymous': False,
+        'vary_on_user': True,
+        'timeout': 3600,
+        'vary_on_url': False,
+        'vary_on_language': True,
+    }
 
     def render(self, request, place, context, *args, **kwargs):
-        links = PortalLink.objects.filter(category=self.category)
+        links = PortalLink.objects.filter(category=self.category).visible_by_user(request.user)
         return self.render_block(request, template_name=self.template_name,
                                 block_title=ugettext('Portal links'),
                                 context={'links': links,
                                          'category': self.category})
 
 
-class PrimaryLinksBlock(LinkBaseBlock):
-    """ Block that renders primary portal links """
-    name = 'primarylinks'
+class PortalLinksBlock(LinkBaseBlock):
+    """Generic block that renders portal links"""
+    name = 'portallinks'
     default_place = 'header'
-    category = 'primary'
-    template_name = 'core/block_primarylinks.html'
-    help_text = _('Block reporesents the Primary Links')
-    verbose_name = _('Primary Links Block')
+    help_text = _('Generic block that renders portal links')
+    verbose_name = _('Portal Links Block')
 
+    config_params = BaseBlock.config_params + [
+        params.Single(
+            name="category",
+            label=_("Portal link category"),
+            choices=settings.PORTAL_LINK_CATEGORIES,
+            default=settings.PORTAL_LINK_CATEGORIES[0][0],
+        ),
+    ]
 
-class SecondaryLinksBlock(LinkBaseBlock):
-    """ Block that renders secondary portal links """
-    name = 'secondarylinks'
-    default_place = 'footer'
-    category = 'secondary'
-    template_name = 'core/block_secondarylinks.html'
-    help_text = _('Block that renders secondary portal links')
-    verbose_name = _('Link Base Block')
+    @property
+    def category(self):
+        return self.get_config().get('category', None).get_value()
+
+    @property
+    def template_name(self):
+        category = self.get_config().get('category', None).get_value()
+        return 'core/block_%slinks.html' % category
 
 
 class ContactInfoBlock(ContentBlock):
@@ -137,6 +182,14 @@ class ContactInfoBlock(ContentBlock):
     default_place = 'aftercontent'
     help_text = _('Block with contact info')
     verbose_name = _('Contact Info block')
+    default_caching_params = {
+        'enabled': False,
+        'only_anonymous': True,
+        'vary_on_user': False,
+        'timeout': 3600,
+        'vary_on_url': True,
+        'vary_on_language': True,
+    }
 
     def render(self, request, place, content, context, *args, **kwargs):
         return self.render_block(
