@@ -4,7 +4,7 @@ from merengue.base.admin import (BaseContentAdmin, RelatedModelAdmin,
                                  BaseCategoryAdmin)
 from merengue.section.admin import SectionContentAdmin
 
-from plugins.forum.models import Forum, ForumCategory, Thread, ForumThreadComment
+from plugins.forum.models import Forum, Thread, ForumThreadComment
 
 from transmeta import get_fallback_fieldname
 
@@ -21,10 +21,11 @@ class ForumSectionAdmin(SectionContentAdmin, ForumAdmin):
     manage_contents = True
 
 
-class ThreadRelatedAdmin(RelatedModelAdmin, BaseContentAdmin):
+class ThreadRelatedAdmin(RelatedModelAdmin):
     html_fields = ('description', )
     removed_fields = ('map_icon', 'commentable', )
     prepopulated_fields = {'slug': (get_fallback_fieldname('name'), )}
+    exclude = ('adquire_global_permissions', )
     related_field = 'forum'
 
     def get_form(self, request, obj=None, **kwargs):
@@ -60,12 +61,12 @@ class ForumThreadCommentRelatedAdmin(RelatedModelAdmin):
 def register(site):
     """ Merengue admin registration callback """
     site.register(ForumThreadComment, admin.ModelAdmin)
-    site.register(ForumCategory, ForumCategoryAdmin)
-    site.register(Forum, ForumAdmin)
     site.register_related(Thread, ThreadRelatedAdmin, related_to=Forum)
     site.register_related(ForumThreadComment, ForumThreadCommentRelatedAdmin, related_to=Thread)
 
 
 def unregister(site):
     """ Merengue admin unregistration callback """
-    site.unregister(Forum)
+    site.unregister(ForumThreadComment)
+    site.unregister_related(Thread, ThreadRelatedAdmin, related_to=Forum)
+    site.unregister_related(ForumThreadComment, ForumThreadCommentRelatedAdmin, related_to=Thread)
