@@ -19,7 +19,7 @@ from merengue.collection.models import IncludeCollectionFilter
 from merengue.collection.utils import create_normalize_collection
 from merengue.pluggable import Plugin
 
-from plugins.news.actions import NewsIndex, NewsRSS
+from plugins.news.actions import NewsIndex
 from plugins.news.blocks import LatestNewsBlock
 from plugins.news.viewlets import LatestNewsViewlet, AllNewsViewlet
 
@@ -37,7 +37,7 @@ class PluginConfig(Plugin):
     )
 
     def get_actions(self):
-        return [NewsIndex, NewsRSS]
+        return [NewsIndex]
 
     def get_blocks(self):
         return [LatestNewsBlock]
@@ -45,19 +45,14 @@ class PluginConfig(Plugin):
     def get_viewlets(self):
         return [LatestNewsViewlet, AllNewsViewlet]
 
-    def section_models(self):
-        return [(NewsItem, NewsItemSectionAdmin)]
-
-    def get_model_admins(self):
+    def models(self):
         return [(NewsCategory, NewsCategoryAdmin),
                 (NewsItem, NewsItemAdmin)]
 
+    def section_models(self):
+        return [(NewsItem, NewsItemSectionAdmin)]
+
     def post_install(self):
         collection = create_normalize_collection('news', u'News', NewsItem,
                                                  create_display_field=True,
                                                  create_filter_field=True)
-        IncludeCollectionFilter.objects.get_or_create(
-            collection=collection,
-            filter_field='expire_date',
-            filter_operator='date_gt',
-            )  # this way, we won't have in count the expired news
